==> huaweicloudsdkeip-3.0.50-py2.py3-none-any.whl: huaweicloudsdkeip/v2/model/neutron_update_floating_ip_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class NeutronUpdateFloatingIpResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'floatingip': 'PostAndPutFloatingIpResp'
    }

    attribute_map = {
        'floatingip': 'floatingip'
    }

    def __init__(self, floatingip=None):
        """NeutronUpdateFloatingIpResponse - a model defined in huaweicloud sdk"""
        
        super(NeutronUpdateFloatingIpResponse, self).__init__()

        self._floatingip = None
        self.discriminator = None

        if floatingip is not None:
            self.floatingip = floatingip

    @property
    def floatingip(self):
        """Gets the floatingip of this NeutronUpdateFloatingIpResponse.


        :return: The floatingip of this NeutronUpdateFloatingIpResponse.
        :rtype: PostAndPutFloatingIpResp
        """
        return self._floatingip

    @floatingip.setter
    def floatingip(self, floatingip):
        """Sets the floatingip of this NeutronUpdateFloatingIpResponse.


        :param floatingip: The floatingip of this NeutronUpdateFloatingIpResponse.
        :type: PostAndPutFloatingIpResp
        """
        self._floatingip = floatingip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NeutronUpdateFloatingIpResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeip-3.0.52-py2.py3-none-any.whl: huaweicloudsdkeip/v2/model/neutron_update_floating_ip_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class NeutronUpdateFloatingIpResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'floatingip': 'PostAndPutFloatingIpResp'
    }

    attribute_map = {
        'floatingip': 'floatingip'
    }

    def __init__(self, floatingip=None):
        """NeutronUpdateFloatingIpResponse - a model defined in huaweicloud sdk"""
        
        super(NeutronUpdateFloatingIpResponse, self).__init__()

        self._floatingip = None
        self.discriminator = None

        if floatingip is not None:
            self.floatingip = floatingip

    @property
    def floatingip(self):
        """Gets the floatingip of this NeutronUpdateFloatingIpResponse.


        :return: The floatingip of this NeutronUpdateFloatingIpResponse.
        :rtype: PostAndPutFloatingIpResp
        """
        return self._floatingip

    @floatingip.setter
    def floatingip(self, floatingip):
        """Sets the floatingip of this NeutronUpdateFloatingIpResponse.


        :param floatingip: The floatingip of this NeutronUpdateFloatingIpResponse.
        :type: PostAndPutFloatingIpResp
        """
        self._floatingip = floatingip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NeutronUpdateFloatingIpResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
